# coding: utf-8

"""
    DeviceServer

    DeviceServer API  # noqa: E501

    The version of the OpenAPI document: 1.0.7
    Contact: david@3adesign.co.uk
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from DeviceServer.configuration import Configuration


class HostConfig(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'host_name': 'str',
        'ip_address': 'str',
        'net_mask': 'str',
        'gateway': 'str',
        'static': 'bool'
    }

    attribute_map = {
        'host_name': 'HostName',
        'ip_address': 'IpAddress',
        'net_mask': 'NetMask',
        'gateway': 'Gateway',
        'static': 'Static'
    }

    def __init__(self, host_name=None, ip_address=None, net_mask=None, gateway=None, static=None, local_vars_configuration=None):  # noqa: E501
        """HostConfig - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._host_name = None
        self._ip_address = None
        self._net_mask = None
        self._gateway = None
        self._static = None
        self.discriminator = None

        self.host_name = host_name
        self.ip_address = ip_address
        self.net_mask = net_mask
        self.gateway = gateway
        self.static = static

    @property
    def host_name(self):
        """Gets the host_name of this HostConfig.  # noqa: E501


        :return: The host_name of this HostConfig.  # noqa: E501
        :rtype: str
        """
        return self._host_name

    @host_name.setter
    def host_name(self, host_name):
        """Sets the host_name of this HostConfig.


        :param host_name: The host_name of this HostConfig.  # noqa: E501
        :type host_name: str
        """
        if self.local_vars_configuration.client_side_validation and host_name is None:  # noqa: E501
            raise ValueError("Invalid value for `host_name`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                host_name is not None and len(host_name) > 100):
            raise ValueError("Invalid value for `host_name`, length must be less than or equal to `100`")  # noqa: E501

        self._host_name = host_name

    @property
    def ip_address(self):
        """Gets the ip_address of this HostConfig.  # noqa: E501


        :return: The ip_address of this HostConfig.  # noqa: E501
        :rtype: str
        """
        return self._ip_address

    @ip_address.setter
    def ip_address(self, ip_address):
        """Sets the ip_address of this HostConfig.


        :param ip_address: The ip_address of this HostConfig.  # noqa: E501
        :type ip_address: str
        """
        if self.local_vars_configuration.client_side_validation and ip_address is None:  # noqa: E501
            raise ValueError("Invalid value for `ip_address`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                ip_address is not None and len(ip_address) > 100):
            raise ValueError("Invalid value for `ip_address`, length must be less than or equal to `100`")  # noqa: E501

        self._ip_address = ip_address

    @property
    def net_mask(self):
        """Gets the net_mask of this HostConfig.  # noqa: E501


        :return: The net_mask of this HostConfig.  # noqa: E501
        :rtype: str
        """
        return self._net_mask

    @net_mask.setter
    def net_mask(self, net_mask):
        """Sets the net_mask of this HostConfig.


        :param net_mask: The net_mask of this HostConfig.  # noqa: E501
        :type net_mask: str
        """
        if self.local_vars_configuration.client_side_validation and net_mask is None:  # noqa: E501
            raise ValueError("Invalid value for `net_mask`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                net_mask is not None and len(net_mask) > 100):
            raise ValueError("Invalid value for `net_mask`, length must be less than or equal to `100`")  # noqa: E501

        self._net_mask = net_mask

    @property
    def gateway(self):
        """Gets the gateway of this HostConfig.  # noqa: E501


        :return: The gateway of this HostConfig.  # noqa: E501
        :rtype: str
        """
        return self._gateway

    @gateway.setter
    def gateway(self, gateway):
        """Sets the gateway of this HostConfig.


        :param gateway: The gateway of this HostConfig.  # noqa: E501
        :type gateway: str
        """
        if self.local_vars_configuration.client_side_validation and gateway is None:  # noqa: E501
            raise ValueError("Invalid value for `gateway`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                gateway is not None and len(gateway) > 100):
            raise ValueError("Invalid value for `gateway`, length must be less than or equal to `100`")  # noqa: E501

        self._gateway = gateway

    @property
    def static(self):
        """Gets the static of this HostConfig.  # noqa: E501


        :return: The static of this HostConfig.  # noqa: E501
        :rtype: bool
        """
        return self._static

    @static.setter
    def static(self, static):
        """Sets the static of this HostConfig.


        :param static: The static of this HostConfig.  # noqa: E501
        :type static: bool
        """
        if self.local_vars_configuration.client_side_validation and static is None:  # noqa: E501
            raise ValueError("Invalid value for `static`, must not be `None`")  # noqa: E501

        self._static = static

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, HostConfig):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, HostConfig):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    DeviceServer

    DeviceServer API  # noqa: E501

    The version of the OpenAPI document: 1.0.6
    Contact: david@3adesign.co.uk
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import DeviceServer
from DeviceServer.api.devices_api import DevicesApi  # noqa: E501
from DeviceServer.rest import ApiException


class TestDevicesApi(unittest.TestCase):
    """DevicesApi unit test stubs"""

    def setUp(self):
        self.api = DeviceServer.api.devices_api.DevicesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_current(self):
        """Test case for get_current

        GET current reading of device  # noqa: E501
        """
        pass

    def test_get_device_device_id_buttons(self):
        """Test case for get_device_device_id_buttons

        GET all buttons for device  # noqa: E501
        """
        pass

    def test_get_device_device_id_leds(self):
        """Test case for get_device_device_id_leds

        GET all leds for device  # noqa: E501
        """
        pass

    def test_get_device_device_id_ports(self):
        """Test case for get_device_device_id_ports

        GET all ports for device  # noqa: E501
        """
        pass

    def test_get_device_device_id_temperature_ports(self):
        """Test case for get_device_device_id_temperature_ports

        GET all temperature ports for device  # noqa: E501
        """
        pass

    def test_get_device_id_port_index(self):
        """Test case for get_device_id_port_index

        GET status of port  # noqa: E501
        """
        pass

    def test_get_device_port_current(self):
        """Test case for get_device_port_current

        GET current reading of device Port  # noqa: E501
        """
        pass

    def test_get_device_port_voltage(self):
        """Test case for get_device_port_voltage

        GET voltage reading of device Port  # noqa: E501
        """
        pass

    def test_get_device_uuid(self):
        """Test case for get_device_uuid

        GET uuid from database  # noqa: E501
        """
        pass

    def test_get_devices(self):
        """Test case for get_devices

        GET list of devices  # noqa: E501
        """
        pass

    def test_get_devices_button(self):
        """Test case for get_devices_button

        GET state of button  # noqa: E501
        """
        pass

    def test_get_devices_index(self):
        """Test case for get_devices_index

        GET single device  # noqa: E501
        """
        pass

    def test_get_devices_led(self):
        """Test case for get_devices_led

        GET state of LED  # noqa: E501
        """
        pass

    def test_get_devices_temperature(self):
        """Test case for get_devices_temperature

        GET temperature reading  # noqa: E501
        """
        pass

    def test_get_fan_speed(self):
        """Test case for get_fan_speed

        GET device fan speed  # noqa: E501
        """
        pass

    def test_get_fan_target_temperature(self):
        """Test case for get_fan_target_temperature

        GET device fan target temperature  # noqa: E501
        """
        pass

    def test_get_fan_temperature(self):
        """Test case for get_fan_temperature

        GET device fan temperature  # noqa: E501
        """
        pass

    def test_get_firmware_version(self):
        """Test case for get_firmware_version

        GET Device Firmware Version  # noqa: E501
        """
        pass

    def test_get_message_from_rx_buffer(self):
        """Test case for get_message_from_rx_buffer

        GET message from RX table  # noqa: E501
        """
        pass

    def test_get_message_from_tx_buffer(self):
        """Test case for get_message_from_tx_buffer

        GET message from TX table  # noqa: E501
        """
        pass

    def test_get_port(self):
        """Test case for get_port

        GET status of port by id  # noqa: E501
        """
        pass

    def test_get_port_states(self):
        """Test case for get_port_states

        GET port states by port id  # noqa: E501
        """
        pass

    def test_get_ports(self):
        """Test case for get_ports

        GET status of all ports  # noqa: E501
        """
        pass

    def test_get_relay_state(self):
        """Test case for get_relay_state

        GET state of relay  # noqa: E501
        """
        pass

    def test_get_temperature_range(self):
        """Test case for get_temperature_range

        GET Temperature Range  # noqa: E501
        """
        pass

    def test_get_temperature_thresholds(self):
        """Test case for get_temperature_thresholds

        GET Temperature Thresholds  # noqa: E501
        """
        pass

    def test_get_voltage(self):
        """Test case for get_voltage

        GET voltage reading of device  # noqa: E501
        """
        pass

    def test_put_device(self):
        """Test case for put_device

        PUT Add device  # noqa: E501
        """
        pass

    def test_put_device_device_id_description(self):
        """Test case for put_device_device_id_description

        PUT a description for a Device  # noqa: E501
        """
        pass

    def test_put_device_device_id_name(self):
        """Test case for put_device_device_id_name

        PUT a name for a Device  # noqa: E501
        """
        pass

    def test_put_device_id_label(self):
        """Test case for put_device_id_label

        PUT a Port label  # noqa: E501
        """
        pass

    def test_put_device_port_module_led_state(self):
        """Test case for put_device_port_module_led_state

        PUT state of Port LED  # noqa: E501
        """
        pass

    def test_put_device_port_module_relay_state(self):
        """Test case for put_device_port_module_relay_state

        PUT state of Port LED  # noqa: E501
        """
        pass

    def test_put_devices_led_index(self):
        """Test case for put_devices_led_index

        PUT state of LED  # noqa: E501
        """
        pass

    def test_put_devices_ports(self):
        """Test case for put_devices_ports

        PUT state of port  # noqa: E501
        """
        pass

    def test_put_port_led_state(self):
        """Test case for put_port_led_state

        PUT state of Port LED  # noqa: E501
        """
        pass

    def test_put_port_port_id_label(self):
        """Test case for put_port_port_id_label

        PUT the label for a Port  # noqa: E501
        """
        pass

    def test_put_port_port_id_state_label(self):
        """Test case for put_port_port_id_state_label

        PUT state label  # noqa: E501
        """
        pass

    def test_put_port_states_port_id(self):
        """Test case for put_port_states_port_id

          # noqa: E501
        """
        pass

    def test_put_ports_pulse(self):
        """Test case for put_ports_pulse

        PUT port into state for period of time  # noqa: E501
        """
        pass

    def test_put_relay_state(self):
        """Test case for put_relay_state

          # noqa: E501
        """
        pass

    def test_put_serial_test_message(self):
        """Test case for put_serial_test_message

        Serial Message Test  # noqa: E501
        """
        pass

    def test_put_state_by_port_id(self):
        """Test case for put_state_by_port_id

        PUT state of port  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    DeviceServer

    DeviceServer API  # noqa: E501

    The version of the OpenAPI document: 1.0.6
    Contact: david@3adesign.co.uk
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import DeviceServer
from DeviceServer.models.db_device_button import DbDeviceButton  # noqa: E501
from DeviceServer.rest import ApiException

class TestDbDeviceButton(unittest.TestCase):
    """DbDeviceButton unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test DbDeviceButton
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = DeviceServer.models.db_device_button.DbDeviceButton()  # noqa: E501
        if include_optional :
            return DbDeviceButton(
                device_id = 'bf325375-e030-4fcc-aa00-917317c5747701234567891011121314151617181920212223242526272829303132333435', 
                button_index = 1, 
                label = '', 
                button_id = ''
            )
        else :
            return DbDeviceButton(
                device_id = 'bf325375-e030-4fcc-aa00-917317c5747701234567891011121314151617181920212223242526272829303132333435',
                button_index = 1,
                button_id = '',
        )

    def testDbDeviceButton(self):
        """Test DbDeviceButton"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    DeviceServer

    DeviceServer API  # noqa: E501

    The version of the OpenAPI document: 1.0.7
    Contact: david@3adesign.co.uk
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from DeviceServer.configuration import Configuration


class Device(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'device_id': 'str',
        'device_index': 'int',
        'device_type': 'str',
        'device_serial': 'str',
        'name': 'str',
        'description': 'str',
        'port_count': 'int',
        'button_count': 'int',
        'led_count': 'int',
        'temperature_port_count': 'int'
    }

    attribute_map = {
        'device_id': 'device_id',
        'device_index': 'device_index',
        'device_type': 'device_type',
        'device_serial': 'device_serial',
        'name': 'name',
        'description': 'description',
        'port_count': 'port_count',
        'button_count': 'button_count',
        'led_count': 'led_count',
        'temperature_port_count': 'temperature_port_count'
    }

    def __init__(self, device_id=None, device_index=None, device_type=None, device_serial=None, name=None, description=None, port_count=None, button_count=None, led_count=None, temperature_port_count=None, local_vars_configuration=None):  # noqa: E501
        """Device - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._device_id = None
        self._device_index = None
        self._device_type = None
        self._device_serial = None
        self._name = None
        self._description = None
        self._port_count = None
        self._button_count = None
        self._led_count = None
        self._temperature_port_count = None
        self.discriminator = None

        self.device_id = device_id
        self.device_index = device_index
        if device_type is not None:
            self.device_type = device_type
        if device_serial is not None:
            self.device_serial = device_serial
        self.name = name
        if description is not None:
            self.description = description
        if port_count is not None:
            self.port_count = port_count
        if button_count is not None:
            self.button_count = button_count
        if led_count is not None:
            self.led_count = led_count
        if temperature_port_count is not None:
            self.temperature_port_count = temperature_port_count

    @property
    def device_id(self):
        """Gets the device_id of this Device.  # noqa: E501


        :return: The device_id of this Device.  # noqa: E501
        :rtype: str
        """
        return self._device_id

    @device_id.setter
    def device_id(self, device_id):
        """Sets the device_id of this Device.


        :param device_id: The device_id of this Device.  # noqa: E501
        :type device_id: str
        """
        if self.local_vars_configuration.client_side_validation and device_id is None:  # noqa: E501
            raise ValueError("Invalid value for `device_id`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                device_id is not None and len(device_id) > 36):
            raise ValueError("Invalid value for `device_id`, length must be less than or equal to `36`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                device_id is not None and len(device_id) < 36):
            raise ValueError("Invalid value for `device_id`, length must be greater than or equal to `36`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                device_id is not None and not re.search(r'[0-9a-f]{8}-[0-9a-f]{4}-4[0-9a-f]{3}-[89ab][0-9a-f]{3}-[0-9a-f]{12}', device_id)):  # noqa: E501
            raise ValueError(r"Invalid value for `device_id`, must be a follow pattern or equal to `/[0-9a-f]{8}-[0-9a-f]{4}-4[0-9a-f]{3}-[89ab][0-9a-f]{3}-[0-9a-f]{12}/`")  # noqa: E501

        self._device_id = device_id

    @property
    def device_index(self):
        """Gets the device_index of this Device.  # noqa: E501


        :return: The device_index of this Device.  # noqa: E501
        :rtype: int
        """
        return self._device_index

    @device_index.setter
    def device_index(self, device_index):
        """Sets the device_index of this Device.


        :param device_index: The device_index of this Device.  # noqa: E501
        :type device_index: int
        """
        if self.local_vars_configuration.client_side_validation and device_index is None:  # noqa: E501
            raise ValueError("Invalid value for `device_index`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                device_index is not None and device_index < 0):  # noqa: E501
            raise ValueError("Invalid value for `device_index`, must be a value greater than or equal to `0`")  # noqa: E501

        self._device_index = device_index

    @property
    def device_type(self):
        """Gets the device_type of this Device.  # noqa: E501


        :return: The device_type of this Device.  # noqa: E501
        :rtype: str
        """
        return self._device_type

    @device_type.setter
    def device_type(self, device_type):
        """Sets the device_type of this Device.


        :param device_type: The device_type of this Device.  # noqa: E501
        :type device_type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                device_type is not None and len(device_type) > 100):
            raise ValueError("Invalid value for `device_type`, length must be less than or equal to `100`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                device_type is not None and len(device_type) < 1):
            raise ValueError("Invalid value for `device_type`, length must be greater than or equal to `1`")  # noqa: E501

        self._device_type = device_type

    @property
    def device_serial(self):
        """Gets the device_serial of this Device.  # noqa: E501


        :return: The device_serial of this Device.  # noqa: E501
        :rtype: str
        """
        return self._device_serial

    @device_serial.setter
    def device_serial(self, device_serial):
        """Sets the device_serial of this Device.


        :param device_serial: The device_serial of this Device.  # noqa: E501
        :type device_serial: str
        """
        if (self.local_vars_configuration.client_side_validation and
                device_serial is not None and len(device_serial) > 32):
            raise ValueError("Invalid value for `device_serial`, length must be less than or equal to `32`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                device_serial is not None and len(device_serial) < 1):
            raise ValueError("Invalid value for `device_serial`, length must be greater than or equal to `1`")  # noqa: E501

        self._device_serial = device_serial

    @property
    def name(self):
        """Gets the name of this Device.  # noqa: E501


        :return: The name of this Device.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Device.


        :param name: The name of this Device.  # noqa: E501
        :type name: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) > 64):
            raise ValueError("Invalid value for `name`, length must be less than or equal to `64`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) < 1):
            raise ValueError("Invalid value for `name`, length must be greater than or equal to `1`")  # noqa: E501

        self._name = name

    @property
    def description(self):
        """Gets the description of this Device.  # noqa: E501


        :return: The description of this Device.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this Device.


        :param description: The description of this Device.  # noqa: E501
        :type description: str
        """
        if (self.local_vars_configuration.client_side_validation and
                description is not None and len(description) > 100):
            raise ValueError("Invalid value for `description`, length must be less than or equal to `100`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                description is not None and len(description) < 1):
            raise ValueError("Invalid value for `description`, length must be greater than or equal to `1`")  # noqa: E501

        self._description = description

    @property
    def port_count(self):
        """Gets the port_count of this Device.  # noqa: E501

        Number of ports available on device  # noqa: E501

        :return: The port_count of this Device.  # noqa: E501
        :rtype: int
        """
        return self._port_count

    @port_count.setter
    def port_count(self, port_count):
        """Sets the port_count of this Device.

        Number of ports available on device  # noqa: E501

        :param port_count: The port_count of this Device.  # noqa: E501
        :type port_count: int
        """
        if (self.local_vars_configuration.client_side_validation and
                port_count is not None and port_count > 100):  # noqa: E501
            raise ValueError("Invalid value for `port_count`, must be a value less than or equal to `100`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                port_count is not None and port_count < 0):  # noqa: E501
            raise ValueError("Invalid value for `port_count`, must be a value greater than or equal to `0`")  # noqa: E501

        self._port_count = port_count

    @property
    def button_count(self):
        """Gets the button_count of this Device.  # noqa: E501

        Number of buttons available on device  # noqa: E501

        :return: The button_count of this Device.  # noqa: E501
        :rtype: int
        """
        return self._button_count

    @button_count.setter
    def button_count(self, button_count):
        """Sets the button_count of this Device.

        Number of buttons available on device  # noqa: E501

        :param button_count: The button_count of this Device.  # noqa: E501
        :type button_count: int
        """
        if (self.local_vars_configuration.client_side_validation and
                button_count is not None and button_count > 100):  # noqa: E501
            raise ValueError("Invalid value for `button_count`, must be a value less than or equal to `100`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                button_count is not None and button_count < 0):  # noqa: E501
            raise ValueError("Invalid value for `button_count`, must be a value greater than or equal to `0`")  # noqa: E501

        self._button_count = button_count

    @property
    def led_count(self):
        """Gets the led_count of this Device.  # noqa: E501

        Number of leds available on device  # noqa: E501

        :return: The led_count of this Device.  # noqa: E501
        :rtype: int
        """
        return self._led_count

    @led_count.setter
    def led_count(self, led_count):
        """Sets the led_count of this Device.

        Number of leds available on device  # noqa: E501

        :param led_count: The led_count of this Device.  # noqa: E501
        :type led_count: int
        """
        if (self.local_vars_configuration.client_side_validation and
                led_count is not None and led_count > 100):  # noqa: E501
            raise ValueError("Invalid value for `led_count`, must be a value less than or equal to `100`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                led_count is not None and led_count < 0):  # noqa: E501
            raise ValueError("Invalid value for `led_count`, must be a value greater than or equal to `0`")  # noqa: E501

        self._led_count = led_count

    @property
    def temperature_port_count(self):
        """Gets the temperature_port_count of this Device.  # noqa: E501

        Number of temperature ports available on device  # noqa: E501

        :return: The temperature_port_count of this Device.  # noqa: E501
        :rtype: int
        """
        return self._temperature_port_count

    @temperature_port_count.setter
    def temperature_port_count(self, temperature_port_count):
        """Sets the temperature_port_count of this Device.

        Number of temperature ports available on device  # noqa: E501

        :param temperature_port_count: The temperature_port_count of this Device.  # noqa: E501
        :type temperature_port_count: int
        """
        if (self.local_vars_configuration.client_side_validation and
                temperature_port_count is not None and temperature_port_count > 100):  # noqa: E501
            raise ValueError("Invalid value for `temperature_port_count`, must be a value less than or equal to `100`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                temperature_port_count is not None and temperature_port_count < 0):  # noqa: E501
            raise ValueError("Invalid value for `temperature_port_count`, must be a value greater than or equal to `0`")  # noqa: E501

        self._temperature_port_count = temperature_port_count

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Device):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Device):
            return True

        return self.to_dict() != other.to_dict()
